package com.goldenwater.slaj.stan.service;

import java.util.List;
import com.goldenwater.slaj.stan.domain.BisStanSelfEvaRep;

public interface IBisStanSelfEvaRepService {
    BisStanSelfEvaRep selectBisStanSelfEvaRepByGuid(String guid);
    List<BisStanSelfEvaRep> selectBisStanSelfEvaRepList(BisStanSelfEvaRep entity);
    int insertBisStanSelfEvaRep(BisStanSelfEvaRep entity);
    int updateBisStanSelfEvaRep(BisStanSelfEvaRep entity);
    int deleteBisStanSelfEvaRepByGuid(String guid);
    int deleteBisStanSelfEvaRepByGuids(String[] guids);
}
